searchData={"items":[{"type":"module","title":"Unleash","doc":"If you have no plans on extending the client, then `Unleash` will be the main\nusage point of the library. Upon starting your app, the client is registered\nwith the unleash server, and two `GenServer`s are started, one to fetch and\npoll for feature flags from the server, and one to send metrics.\n\nConfiguring `:disable_client` to `true` disables both servers as well as\nregistration, while configuring `:disable_metrics` to `true` disables only\nthe metrics `GenServer`.","ref":"Unleash.html"},{"type":"function","title":"Unleash.enabled?/2","doc":"Checks if the given feature is enabled. Checks as though an empty context was\npassed in.","ref":"Unleash.html#enabled?/2"},{"type":"function","title":"Examples - Unleash.enabled?/2","doc":"iex> Unleash.enabled?(:my_feature, false)\n    false\n\n    iex> Unleash.enabled?(:my_feature, true)\n    true","ref":"Unleash.html#enabled?/2-examples"},{"type":"function","title":"Unleash.enabled?/3","doc":"Checks if the given feature is enabled.\n\nIf `:disable_client` is `true`, simply returns the given `default`.\n\nIf `:disable_metrics` is `true`, nothing is logged about the given toggle.","ref":"Unleash.html#enabled?/3"},{"type":"function","title":"Examples - Unleash.enabled?/3","doc":"iex> Unleash.enabled?(:my_feature)\n    false\n\n    iex> Unleash.enabled?(:my_feature, context)\n    false\n\n    iex> Unleash.enabled?(:my_feature, context, true)\n    false","ref":"Unleash.html#enabled?/3-examples"},{"type":"function","title":"Unleash.get_variant/3","doc":"Returns a variant for the given name.\n\nIf `:disable_client` is `true`, returns the fallback.\n\nA [variant](https://unleash.github.io/docs/beta_features#feature-toggle-variants)\nallows for more complicated toggling than a simple `true`/`false`, instead\nreturning one of the configured variants depending on whether or not there\nare any overrides for a given context value as well as factoring in the\nweights for the various weight options.","ref":"Unleash.html#get_variant/3"},{"type":"function","title":"Examples - Unleash.get_variant/3","doc":"iex> Unleash.get_variant(:test)\n    %{enabled: true, name: \"test\", payload: %{...}}\n\n    iex> Unleash.get_variant(:test)\n    %{enabled: false, name: \"disabled\"}","ref":"Unleash.html#get_variant/3-examples"},{"type":"function","title":"Unleash.is_enabled?/2","doc":"Aliased to `enabled?/2`","ref":"Unleash.html#is_enabled?/2"},{"type":"function","title":"Unleash.is_enabled?/3","doc":"Aliased to `enabled?/3`","ref":"Unleash.html#is_enabled?/3"},{"type":"type","title":"Unleash.context/0","doc":"The context needed for a few activation strategies. Check their documentation\nfor the required key.\n\n* `:user_id` is the ID of the user interacting _with your system_, can be any\n  `String.t()`\n* `session_id` is the ID of the current session _in your system_, can be any\n  `String.t()`\n* `remote_address` is the address of the user interacting _with your system_,\n  can be any `String.t()`","ref":"Unleash.html#t:context/0"},{"type":"module","title":"Unleash.Cache","doc":"This module is a cache backed by an ETS table. We use it to allow for multiple\nthreads to read the feature flag values concurrently on top of minimizing\nnetwork calls","ref":"Unleash.Cache.html"},{"type":"function","title":"Unleash.Cache.cache_table_name/0","doc":"","ref":"Unleash.Cache.html#cache_table_name/0"},{"type":"function","title":"Unleash.Cache.get_all_feature_names/1","doc":"Will return all values currently stored in the cache","ref":"Unleash.Cache.html#get_all_feature_names/1"},{"type":"function","title":"Unleash.Cache.get_feature/2","doc":"Will return the feature for the given name stored in the cache","ref":"Unleash.Cache.html#get_feature/2"},{"type":"function","title":"Unleash.Cache.get_features/1","doc":"Will return all features stored in the cache","ref":"Unleash.Cache.html#get_features/1"},{"type":"function","title":"Unleash.Cache.init/2","doc":"Will create a new ETS table named `:unleash_cache`","ref":"Unleash.Cache.html#init/2"},{"type":"function","title":"Unleash.Cache.upsert_features/2","doc":"Will upsert (create or update) the given features in the cache\n\nThis will clear the existing peristed features to prevent stale reads","ref":"Unleash.Cache.html#upsert_features/2"},{"type":"behaviour","title":"Unleash.HTTPClientAdapter","doc":"Behaviour that all http clients must implement in order to\nbe compatible","ref":"Unleash.HTTPClientAdapter.html"},{"type":"callback","title":"Unleash.HTTPClientAdapter.get/2","doc":"","ref":"Unleash.HTTPClientAdapter.html#c:get/2"},{"type":"callback","title":"Unleash.HTTPClientAdapter.post/3","doc":"","ref":"Unleash.HTTPClientAdapter.html#c:post/3"},{"type":"type","title":"Unleash.HTTPClientAdapter.error_reason/0","doc":"","ref":"Unleash.HTTPClientAdapter.html#t:error_reason/0"},{"type":"type","title":"Unleash.HTTPClientAdapter.header/0","doc":"","ref":"Unleash.HTTPClientAdapter.html#t:header/0"},{"type":"type","title":"Unleash.HTTPClientAdapter.headers/0","doc":"","ref":"Unleash.HTTPClientAdapter.html#t:headers/0"},{"type":"type","title":"Unleash.HTTPClientAdapter.response/0","doc":"","ref":"Unleash.HTTPClientAdapter.html#t:response/0"},{"type":"module","title":"Unleash.MojitoClient","doc":"Http client using Mojito","ref":"Unleash.MojitoClient.html"},{"type":"module","title":"Unleash.Plug","doc":"An extra fancy `Plug` and utility functions to help when developing `Plug`\nor `Phoenix`-based applications. It automatically puts together a\n`t:Unleash.context/0` under the `Plug.Conn`'s `Plug.assigns/0`.\n\nTo use, call `plug Unleash.Plug` in your plug pipeline. It depends on the\nsession, and requires being after `:fetch_session` to work. It accepts the\nfollowing options:\n\n* `:user_id`: The key under which the user's ID is found in the session.\n* `:session_id`: The key under wwhich the session ID is found in the\n  session.\n\nAfter which, `enabled?/3` is usable.\n\nIf you are _also_ using `PhoenixGon` in your application, you can call\n`put_feature/3` to put a specific feature flag into the gon object for\nusing on the client side.","ref":"Unleash.Plug.html"},{"type":"function","title":"Unleash.Plug.enabled?/3","doc":"Given a `t:Plug.Conn/0`, a feature, and (optionally) a boolean, return\nwhether or not a feature is enabled. This requires this plug to be a part\nof the plug pipeline, as it will construct an `t:Unleash.context()/0` out\nof the session.","ref":"Unleash.Plug.html#enabled?/3"},{"type":"function","title":"Examples - Unleash.Plug.enabled?/3","doc":"iex> Unleash.Plug.enabled?(conn, :test)\n    false\n\n    iex> Unleash.Plug.enabled?(conn, :test, true)\n    true","ref":"Unleash.Plug.html#enabled?/3-examples"},{"type":"function","title":"Unleash.Plug.put_feature/3","doc":"If you are using `PhoenixGon`, you can call this to put a feature in the\ngon object to be used on the client side. It will be available under\n`window.Gon.getAssets('features')`. It listens to the options that\nare configured by `PhoenixGon.Pipeline`.","ref":"Unleash.Plug.html#put_feature/3"},{"type":"function","title":"Examples - Unleash.Plug.put_feature/3","doc":"iex> Unleash.Plug.put_feature(conn, :test)\n    %Plug.Conn{}\n\n    iex> Unleash.Plug.enabled?(conn, :test, true)\n    %Plug.Conn{}","ref":"Unleash.Plug.html#put_feature/3-examples"},{"type":"module","title":"Unleash.Repo","doc":"This genserver polls the unleash service each time the given interval has\nelapsed, refreshing both our local ETS cache and the backup state file if the\nflag state has diverged.\n\nThe following configuration values are used:\n\nConfig.features_period(): polling interval - default 15 seconds\nConfig.retries(): number of time the call to refresh values is allowed to retry - default -1 (0)","ref":"Unleash.Repo.html"},{"type":"function","title":"Unleash.Repo.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Unleash.Repo.html#child_spec/1"},{"type":"function","title":"Unleash.Repo.get_all_feature_names/0","doc":"","ref":"Unleash.Repo.html#get_all_feature_names/0"},{"type":"function","title":"Unleash.Repo.get_feature/1","doc":"","ref":"Unleash.Repo.html#get_feature/1"},{"type":"function","title":"Unleash.Repo.init/1","doc":"","ref":"Unleash.Repo.html#init/1"},{"type":"function","title":"Unleash.Repo.start_link/1","doc":"","ref":"Unleash.Repo.html#start_link/1"},{"type":"module","title":"Unleash.ReqClient","doc":"Http client using Req","ref":"Unleash.ReqClient.html"},{"type":"behaviour","title":"Unleash.Strategies","doc":"Used to get all available strategies in the client. You can add your\nstrategies to the client by extending this module:\n\n```elixir\ndefmodule MyApp.Strategies do\n  @behaviour Unleash.Strategies\n\n  def strategies, do: Unleash.Strategies.strategies() ++ []\nend\n```\n\nand then setting it in your configuration:\n\n```elixir\nconfig :unleash, Unleash, strategies: MyApp.Strategies\n```","ref":"Unleash.Strategies.html"},{"type":"function","title":"Unleash.Strategies.strategies/0","doc":"Returns all the strategies that are supported by this client. They can be\nviewed under `Strategy`.\n\nFor completeness, the list is:\n\n* `userWithId`: `Unleash.Strategy.ActiveForUsersWithId`\n* `applicationHostname`: `Unleash.Strategy.ApplicationHostname`\n* `default`: `Unleash.Strategy.Default`\n* `gradualRolloutRandom`: `Unleash.Strategy.GradualRolloutRandom`\n* `gradualRolloutSessionId`: `Unleash.Strategy.GradualRolloutSessionId`\n* `gradualRolloutUserId`: `Unleash.Strategy.GradualRolloutUserId`\n* `remoteAddress`: `Unleash.Strategy.RemoteAddress`","ref":"Unleash.Strategies.html#strategies/0"},{"type":"callback","title":"Unleash.Strategies.strategies/0","doc":"Should return a list of all the avilable strategies in the format\n`{\"name\", Module}`. The name must match the name of the strategy in the\nUnleash server, and the module must implement the `Unleash.Strategy` behaviour.","ref":"Unleash.Strategies.html#c:strategies/0"},{"type":"behaviour","title":"Unleash.Strategy","doc":"Used to extend the client and create custom strategies. To do so, `use` this\nmodule within your custom strategy and implmenent `c:enabled?/2`. Provide a\nname that is human-readable, as it is logged.\n\n```elixir\ndefmodule MyApp.CustomStrategy\n  use Unleash.Strategy, name: \"CustomStrategy\"\n\n  def enabled?(_params, _context), do: true\nend\n```","ref":"Unleash.Strategy.html"},{"type":"callback","title":"Unleash.Strategy.enabled?/2","doc":"You can implmenet this callback a couple of ways, returning a bare `boolean()`\nor a `{boolean, map()}`. The latter is preferred, as it generates a\n`:debug` level log entry detailing the name of the strategy, the result, and\nthe contents of `map()`, in an effort to help understand why the result was\nwhat it was.","ref":"Unleash.Strategy.html#c:enabled?/2"},{"type":"callback","title":"Arguments - Unleash.Strategy.enabled?/2","doc":"* `parameters` - A map of paramters returned from the Unleash server. This\n  can be whatever you like, such as a configured list of `userIds`.\n* `context` - The context passed into `Unleash.enabled?/3`.","ref":"Unleash.Strategy.html#c:enabled?/2-arguments"},{"type":"callback","title":"Examples - Unleash.Strategy.enabled?/2","doc":"```elixir\n@behaviour Unleash.Strategy\n\ndef enabled?(params, context), do: {false, params}\n\ndef enabled(params, %{}), do: false\n```","ref":"Unleash.Strategy.html#c:enabled?/2-examples"},{"type":"module","title":"Unleash.Strategy.ActiveForUsersWithId","doc":"Requires `:user_id` in `t:Unleash.context/0`\n\nBased on the\n[`userWithId`](https://unleash.github.io/docs/activation_strategy#userwithid)\nstrategy.","ref":"Unleash.Strategy.ActiveForUsersWithId.html"},{"type":"module","title":"Unleash.Strategy.ApplicationHostname","doc":"Does not require anything in `t:Unleash.context/0`\n\nBased on the\n[`applicationHostname`](https://unleash.github.io/docs/activation_strategy#applicationhostname)\nstrategy.","ref":"Unleash.Strategy.ApplicationHostname.html"},{"type":"function","title":"Unleash.Strategy.ApplicationHostname.enabled?/2","doc":"","ref":"Unleash.Strategy.ApplicationHostname.html#enabled?/2"},{"type":"module","title":"Unleash.Strategy.Constraint","doc":"Module that is used to verify\n[constraints](https://www.unleash-hosted.com/docs/strategy-constraints/) are\nmet.\n\nThese constraints allow for very complex and specifc strategies to be\nenacted by allowing users to specify context values to include or exclude.\n\n- DATE_AFTER\n- DATE_BEFORE\n- IN\n- NOT_IN\n- NUM_EQ\n- NUM_GT\n- NUM_GTE\n- NUM_LT\n- NUM_LTE\n- SEMVER_EQ\n- SEMVER_GT\n- SEMVER_LT\n- STR_CONTAINS\n- STR_ENDS_WITH\n- STR_STARTS_WITH","ref":"Unleash.Strategy.Constraint.html"},{"type":"function","title":"Unleash.Strategy.Constraint.verify_all/2","doc":"","ref":"Unleash.Strategy.Constraint.html#verify_all/2"},{"type":"module","title":"Unleash.Strategy.Default","doc":"Does not require anything in `t:Unleash.context/0`\n\nBased on the\n[`default`](https://unleash.github.io/docs/activation_strategy#default)\nstrategy.","ref":"Unleash.Strategy.Default.html"},{"type":"function","title":"Unleash.Strategy.Default.enabled?/2","doc":"","ref":"Unleash.Strategy.Default.html#enabled?/2"},{"type":"module","title":"Unleash.Strategy.FlexibleRollout","doc":"Can depend on `:user_id` or `:session_id` in `t:Unleash.context/0`\n\nBased on the\n[`flexibleRollout`](https://unleash.github.io/docs/activation_strategy#flexiblerollout)\nstrategy.","ref":"Unleash.Strategy.FlexibleRollout.html"},{"type":"function","title":"Unleash.Strategy.FlexibleRollout.enabled?/2","doc":"","ref":"Unleash.Strategy.FlexibleRollout.html#enabled?/2"},{"type":"module","title":"Unleash.Strategy.GradualRolloutRandom","doc":"Does not require anything in `t:Unleash.context/0`\n\nBased on the\n[`gradualRollourRandom`](https://unleash.github.io/docs/activation_strategy#gradualrolloutrandom)\nstrategy.","ref":"Unleash.Strategy.GradualRolloutRandom.html"},{"type":"module","title":"Unleash.Strategy.GradualRolloutSessionId","doc":"Requires `:session_id` in `t:Unleash.context/0`\n\nBased on the\n[`gradualRolloutSessionId`](https://unleash.github.io/docs/activation_strategy#gradualrolloutsessionid)\nstrategy.","ref":"Unleash.Strategy.GradualRolloutSessionId.html"},{"type":"function","title":"Unleash.Strategy.GradualRolloutSessionId.enabled?/2","doc":"","ref":"Unleash.Strategy.GradualRolloutSessionId.html#enabled?/2"},{"type":"module","title":"Unleash.Strategy.GradualRolloutUserId","doc":"Requires `:user_id` in `t:Unleash.context/0`\n\nBased on the\n[`gradualRolloutUserId`](https://unleash.github.io/docs/activation_strategy#gradualrolloutuserid)\nstrategy.","ref":"Unleash.Strategy.GradualRolloutUserId.html"},{"type":"function","title":"Unleash.Strategy.GradualRolloutUserId.enabled?/2","doc":"","ref":"Unleash.Strategy.GradualRolloutUserId.html#enabled?/2"},{"type":"module","title":"Unleash.Strategy.RemoteAddress","doc":"Requires `:remote_address` in `t:Unleash.context/0`\n\nBased on the\n[`remoteAddress`](https://unleash.github.io/docs/activation_strategy#remoteaddress)\nstrategy.","ref":"Unleash.Strategy.RemoteAddress.html"},{"type":"module","title":"Unleash.Strategy.Utils","doc":"Utilities that might help you create your own strategies.\n\nAutomatically `alias`ed when `use`ing `Unleash.Strategy`","ref":"Unleash.Strategy.Utils.html"},{"type":"function","title":"Unleash.Strategy.Utils.in_list?/3","doc":"Given a comma-separated list and a member, check to see if the member is in\nthe list. An optional transformation function can be passed in to apply\nto the items in the list.","ref":"Unleash.Strategy.Utils.html#in_list?/3"},{"type":"function","title":"Examples - Unleash.Strategy.Utils.in_list?/3","doc":"iex> in_list?(\"a,B,c,D\", \"b\", &String.downcase/1)\n    true\n\n    iex> in_list?(\"a,B,c,D\", \"b\")\n    false","ref":"Unleash.Strategy.Utils.html#in_list?/3-examples"},{"type":"function","title":"Unleash.Strategy.Utils.normalize/3","doc":"Given an ID and group ID, normalize them using a `Murmur` hash. Used in all\nstrategies that provide \"stickiness\".\n\nSee the\n[`gradualRolloutUserId`](https://unleash.github.io/docs/activation_strategy#gradualrolloutuserid)\nstrategy.","ref":"Unleash.Strategy.Utils.html#normalize/3"},{"type":"function","title":"Unleash.Strategy.Utils.normalize_variant/3","doc":"","ref":"Unleash.Strategy.Utils.html#normalize_variant/3"},{"type":"function","title":"Unleash.Strategy.Utils.parse_int/1","doc":"Parse a string to a non-negative integer, returning only the number\nor 0 if it isn't just a number.","ref":"Unleash.Strategy.Utils.html#parse_int/1"},{"type":"function","title":"Examples - Unleash.Strategy.Utils.parse_int/1","doc":"iex> parse_int(\"5\")\n    5\n\n    iex> parse_int(\"5ab23a\")\n    0\n\n    iex> parse_int(5)\n    5","ref":"Unleash.Strategy.Utils.html#parse_int/1-examples"},{"type":"extras","title":"Unleash","doc":"# Unleash\n\n`Unleash` is a client for the\n[Unleash Toggle Service](https://unleash.github.io/).\n\nThe primary use is `Unleash.enabled?/2` or `Unleash.enabled?/3` to check whether\nor not the given feature flag is enabled.\n\n```elixir\niex> Unleash.enabled?(:my_feature)\nfalse\n\niex> Unleash.enabled?(:my_feature, true)\ntrue\n\niex> context = %{user_id: \"ID\", custom_field: \"Unleash\"}\n\niex> Unleash.enabled?(:my_feature, context)\ntrue\n\niex> Unleash.enabled?(:my_feature, context, false)\ntrue\n```\n\nContext fields are transformed internally when validated against constraints,\ne.g. `:user_id` becomes `\"userId\"`.","ref":"readme.html"},{"type":"extras","title":"Installation - Unleash","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `unleash_ex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:unleash, \"~> 1.11\"}\n  ]\nend\n```\n\n\nUnleash works by default with [Req](https://hex.pm/packages/req), so make sure to explicit declare it in your list of dependencies.\nFor backward compatibility reasons, Unleash also works with [Mojito](https://hex.pm/packages/mojito).\nYou can use your own HTTP client module by implementing the `Unleash.HTTPClientAdapter` behaviour and passing the module name in the `:http_client` configuration.","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Unleash","doc":"There are many configuration options available, and they are listed below with\ntheir defaults. These go into the relevant `config/*.exs` file.\n\n```elixir\nconfig :unleash, Unleash,\n  url: \"\", # The URL of the Unleash server to connect to, should include up to http://base.url/api\n  appname: \"\", # The app name, used for registration\n  instance_id: \"\", # The instance ID, used for metrics tracking\n  metrics_period: 10 * 60 * 1000, # Send metrics every 10 minutes, in milliseconds\n  features_period: 15 * 1000, # Poll for new flags every 15 seconds, in milliseconds\n  strategies: Unleash.Strategies, # Which module to request for toggle strategies\n  backup_file: nil, # Backup file in the event that contacting the server fails\n  custom_http_headers: [], # A keyword list of custom headers to send to the server\n  disable_client: false, # Whether or not to enable the client\n  disable_metrics: false, # Whether or not to send metrics,\n  retries: -1 # How many times to retry on failure, -1 disables limit\n  app_env: :dev # Which environment we're in\n  http_client: Unleash.ReqClient # What http client will be used. can be Unleash.ReqClient or Unleash.MojitoClient out of the box\n```\n\n`:custom_http_headers` should follow the format prescribed by\n`t:Unleash.HTTPClientAdapter/0`\n\n`:strategies` should be a module that implements\n`c:Unleash.Strategies.strategies/0`. See [Extensibility](#extensibility)\nfor more information.","ref":"readme.html#configuration"},{"type":"extras","title":"Extensibility - Unleash","doc":"If you need to create your own strategies, you can extend the `Unleash` client\nby implementing the callbacks in both `Unleash.Strategy` and\n`Unleash.Strategies` as well as passing your new `Strategies` module in as\nconfiguration:\n\n1. Create your new strategy. See `Unleash.Strategy` for details on the correct\n    API and `Unleash.Strategy.Utils` for helpful utilities.\n\n    ```elixir\n    defmodule MyApp.Strategy.Environment do\n      use Unleash.Strategy\n\n      def enabled?(%{\"environments\" => environments}, _context) do\n        with {:ok, environment} <- MyApp.Config.get_environment(),\n             environment = List.to_string(environment) do\n          {Utils.in_list?(environments, environment, &String.downcase/1),\n           %{environment: environment, environments: environments}}\n        end\n      end\n    end\n    ```\n\n1. Create a new strategies module. See `Unleash.Strategies` for details on the correct\n    API.\n\n    ```elixir\n    defmodule MyApp.Strategies do\n      @behaviour Unleash.Strategies\n\n      def strategies do\n        [{\"environment\", MyApp.Strategy.Environment}] ++ Unleash.Strategies.strateges()\n      end\n    end\n    ```\n\n1. Configure your application to use your new strategies list.\n\n    ```elixir\n    config :unleash, Unleash, strategies: MyApp.Strategies\n    ```","ref":"readme.html#extensibility"},{"type":"extras","title":"Telemetry events - Unleash","doc":"From Unleash 1.9, telemetry events  are emitted by the Unleash client\nlibrary. You can attach to these events and collect metrics or use the `Logger`,\nfor example:\n\n```elixir\n# An example of checking if Unleash server is reachable during the periodic\n# features fetch.\n:ok =\n  :telemetry.attach_many(\n    :duffel_core_feature_heatbeat_metric,\n    [\n      [:unleash, :client, :fetch_features, :stop],\n      [:unleash, :client, :fetch_features, :exception]\n    ],\n    fn [:unleash, :client, :fetch_features, action],\n        _measurements,\n        metadata,\n        _config ->\n      require Logger\n\n      http_status = metadata[:http_response_status]\n\n      if action == :stop and http_status in [200, 304] do\n        Logger.info(\"Fetching features are ok\")\n      else\n        Logger.info(\"Error on fetching features!!!\")\n      end\n    end,\n    %{}\n  )\n```\n\nThe following events are emitted by the Unleash library:\n\n* `[:unleash, :feature, :enabled?, :start]` - dispatched by `Unleash` whenever\na feature state has been requested.\n  * Measurement:  `%{system_time: system_time, monotonic_time: monotonic_time}`\n  * Metadata: `%{appname: String.t(), instance_id: String.t(), feature: String.t()}`\n* `[:unleash, :feature, :enabled?, :stop]` - dispatched by `Unleash` whenever\na feature check has successfully returned a result.\n  * Measurement:  `%{duration: native_time, monotonic_time: monotonic_time}`\n  * Metadata: `%{appname: String.t(), instance_id: String.t(), feature: String.t(), result: boolean(), reason: atom(), strategy_evaluations: [{String.t(), boolean()}], feature_enabled: boolean()}`\n* `[:unleash, :feature, :enabled?, :exception]` - dispatched by `Unleash` after\nexceptions on fetching a feature's activation state.\n  * Measurement:  `%{duration: native_time, monotonic_time: monotonic_time}`\n  * Metadata: `%{appname: String.t(), instance_id: String.t(), feature: String.t(), kind: :throw | :error | :exit, reason: term(), stacktrace: Exception.stacktrace()}`\n* `[:unleash, :client, :fetch_features, :start]` - dispatched by `Unleash.Client` whenever\nit start to fetch features from a remote Unleash server.\n  * Measurement:  `%{system_time: system_time, monotonic_time: monotonic_time}`\n  * Metadata: `%{appname: String.t(), instance_id: String.t(), etag: String.t() | nil, url: String.t()}`\n* `[:unleash, :client, :fetch_features, :stop]` - dispatched by `Unleash.Client` whenever\nit finishes to fetch features from a remote Unleash server.\n  * Measurement:  `%{duration: native_time, monotonic_time: monotonic_time}`\n  * Metadata: `%{appname: String.t(), instance_id: String.t(), etag: String.t() | nil, url: String.t(), http_response_status: pos_integer | nil, error: struct() | nil}`\n* `[:unleash, :client, :fetch_features, :exception]` - dispatched by `Unleash.Client` after\nexceptions on fetching features.\n  * Measurement:  `%{duration: native_time, monotonic_time: monotonic_time}`\n  * Metadata: `%{appname: String.t(), instance_id: String.t(), etag: String.t() | nil, url: String.t(), kind: :throw | :error | :exit, reason: term(), stacktrace: Exception.stacktrace()}`\n* `[:unleash, :client, :register, :start]` - dispatched by `Unleash.Client` whenever\nit starts to register in an Unleash server.\n  * Measurement:  `%{system_time: system_time, monotonic_time: monotonic_time}`\n  * Metadata: `%{appname: String.t(), instance_id: String.t(), url: String.t(), sdk_version: String.t(), strategies: [String.t()], interval: pos_integer}`\n* `[:unleash, :client, :register, :stop]` - dispatched by `Unleash.Client` whenever\nit finishes to register in an Unleash server.\n  * Measurement:  `%{duration: native_time, monotonic_time: monotonic_time}`\n  * Metadata: `%{appname: String.t(), instance_id: String.t(), url: String.t(), sdk_version: String.t(), strategies: [String.t()], interval: pos_integer, http_response_status: pos_integer | nil, error: struct() | nil}`\n* `[:unleash, :client, :register, :exception]` - dispatched by `Unleash.Client` after\nexceptions on registering in an Unleash server.\n  * Measurement:  `%{duration: native_time, monotonic_time: monotonic_time}`\n  * Metadata: `%{appname: String.t(), instance_id: String.t(), url: String.t(), sdk_version: String.t(), strategies: [String.t()], interval: pos_integer, kind: :throw | :error | :exit, reason: term(), stacktrace: Exception.stacktrace()}`\n* `[:unleash, :client, :push_metrics, :start]` - dispatched by `Unleash.Client` whenever\nit starts to push metrics to an Unleash server.\n  * Measurement:  `%{system_time: system_time, monotonic_time: monotonic_time}`\n  * Metadata: `%{appname: String.t(), instance_id: String.t(), url: String.t(), metrics_payload: %{ :bucket => %{:start => String.t(), :stop => String.t(), toggles: %{\n    String.t() => %{ :yes => pos_integer(), :no => pos_integer() } } } }\n  }`\n* `[:unleash, :client, :push_metrics, :stop]` - dispatched by `Unleash.Client` whenever\nit finishes to push metrics to an Unleash server.\n  * Measurement:  `%{duration: native_time, monotonic_time: monotonic_time}`\n  * Metadata: `%{appname: String.t(), instance_id: String.t(), url: String.t(), http_response_status: pos_integer | nil, error: struct() | nil, metrics_payload: %{ :bucket => %{:start => String.t(), :stop => String.t(), toggles: %{\n    String.t() => %{ :yes => pos_integer(), :no => pos_integer() } } } } }`\n* `[:unleash, :client, :push_metrics, :exception]` - dispatched by `Unleash.Client` after\nexceptions on pushing metrics to an Unleash server.\n  * Measurement:  `%{duration: native_time, monotonic_time: monotonic_time}`\n  * Metadata: `%{appname: String.t(), instance_id: String.t(), url: String.t(), kind: :throw | :error | :exit, reason: term(), stacktrace: Exception.stacktrace(), metrics_payload: %{ :bucket => %{:start => String.t(), :stop => String.t(), toggles: %{\n    String.t() => %{ :yes => pos_integer(), :no => pos_integer() } } } } }`\n* `[:unleash, :repo, :schedule]` - dispatched by `Unleash.Repo` when scheduling a poll to the server for metrics\n  * Metadata: `%{appname: String.t(), instance_id: String.t(), retries: integer(), etag: String.t(), interval: pos_integer()}`\n* `[:unleash, :repo, :backup_file_update]` - dispatched by `Unleash.Repo` when it writes features to the backup file.\n  * Metadata: `%{appname: String.t(), instance_id: String.t(), content: String.t(), filename: String.t()}`\n* `[:unleash, :repo, :disable_polling]` - dispatched by `Unleash.Repo` when polling gets\ndisabled due to retries running out or zero retries being specified initially.\n  * Metadata: `%{appname: String.t(), instance_id: String.t(), retries: integer(), etag: String.t()}`\n* `[:unleash, :repo, :features_update]` - dispatched by `Unleash.Repo` when features are updated.\n  * Metadata: `%{appname: String.t(), instance_id: String.t(), retries: integer(), etag: String.t(), source: :remote | :cache | :backup_file}`","ref":"readme.html#telemetry-events"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}